#!/bin/sh

. /etc/script/lib/command.sh

APKG_PKG_DIR=/usr/local/AppCentral/photo-gallery
PG_WEB_DIR=/volume1/Web/photo-gallery

AS_NOHUP=/usr/bin/nohup
AS_PHP=/usr/builtin/bin/php
LOG_FILE=${APKG_PKG_DIR}/log/daemon.log
PID_FILE=/var/run/photo-gallery-daemon.pid
AS_CONF=/usr/builtin/etc/apache2/asustor.conf
SUSPEND_SCRIPT=/usr/local/etc/init.d/P10photo-gallery

MAX_WORKERS=3
WORKER_PRIORITY=19

insert_php_extension()
{
	NAS_FW_VER=`/usr/bin/confutil -get /etc/nas.conf Basic Version | /usr/bin/awk -F'.' '{print $1"."$2}'`
	NAS_ARCH=`/bin/uname -m`
	AS_EXT=`/usr/builtin/bin/php -m 2>/dev/null | grep asustor`

	if [ x"${NAS_FW_VER}" = x"2.1" ] && [ x"${AS_EXT}" != x"asustor" ]; then
		cp -f ${APKG_PKG_DIR}/php_ext/asustor.ini            /usr/builtin/etc/php5/conf.d/
		cp -f ${APKG_PKG_DIR}/php_ext/asustor-${NAS_ARCH}.so /usr/builtin/lib/php/20090626/asustor.so

		/usr/builtin/etc/init.d/S54apache2 restart
	fi
}

run_apc_clear_cache()
{
	# check Apache2 service settings
	EnableHttp=`/usr/bin/confutil -get $AS_CONF "Web Server" EnableHttp`
	EnableHttps=`/usr/bin/confutil -get $AS_CONF "Web Server" EnableHttps`
	HttpPort=`/usr/bin/confutil -get $AS_CONF "Web Server" HttpPort`
	HttpsPort=`/usr/bin/confutil -get $AS_CONF "Web Server" HttpsPort`

	if [ x"${EnableHttp}" = x"Yes" ]; then
		BASE_URL="http://localhost:${HttpPort}"
	elif [ x"${EnableHttps}" = x"Yes" ]; then
		BASE_URL="https://localhost:${HttpsPort}"
	else
		return -1
	fi

	# run apc clear cache script
	${AS_PHP} ${APKG_PKG_DIR}/script/run_apc_clear.php ${BASE_URL}
}

case $1 in

	start | resume)
		ln -sf ${APKG_PKG_DIR}/CONTROL/start-stop.sh ${SUSPEND_SCRIPT}

		# insert php extension if firmware version is 2.1.1
		insert_php_extension

		# clean up apc cache
		run_apc_clear_cache
		# link Libav lib to environment
		#/bin/ln -sf /usr/local/AppCentral/photo-gallery/lib/* /usr/local/lib/ 
		#/sbin/ldconfig
		
		# run photo-gallery daemon
		cd ${PG_WEB_DIR}
		#nice -n 19 ${AS_NOHUP} ${AS_PHP} index.php console/daemon start ${MAX_WORKERS} ${WORKER_PRIORITY} > /dev/null 2>&1
		${AS_NOHUP} ${AS_PHP} index.php console/daemon start ${MAX_WORKERS} ${WORKER_PRIORITY} > ${LOG_FILE} 2>&1
		;;

	stop | suspend)
		if [ x"$@" = x"stop" ]; then
			rm -f ${SUSPEND_SCRIPT}
		fi
		${AS_KILL} `cat ${PID_FILE} 2> /dev/null` 2> /dev/null
		;;

	*)
		echo "usage: $0 {start|stop}"
		exit 1
		;;
		
esac

exit 0
